summaryrefslogtreecommitdiff
path: root/tests/Process_Mutex_Test.cpp
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-01-08 07:07:14 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-01-08 07:07:14 +0000
commit1ce2535df18f1ee5337c241a9576e886cb50c9a3 (patch)
treeedab1d3405402c1b43fac3f01bedc456a28d43d3 /tests/Process_Mutex_Test.cpp
parent14e979407ee8429aeeeddaf6a6b9fc545437fe64 (diff)
downloadATCD-1ce2535df18f1ee5337c241a9576e886cb50c9a3.tar.gz
foo
Diffstat (limited to 'tests/Process_Mutex_Test.cpp')
-rw-r--r--tests/Process_Mutex_Test.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/Process_Mutex_Test.cpp b/tests/Process_Mutex_Test.cpp
index 483b305a495..2cf2ee5913f 100644
--- a/tests/Process_Mutex_Test.cpp
+++ b/tests/Process_Mutex_Test.cpp
@@ -108,19 +108,19 @@ main (int argc, char *argv[])
s_argv[4] = 0;
s_argv[5] = 0;
- // Spawn ACE_MAX_ITERATIONS processes which will contend for the lock
- ACE_Process servers[ACE_MAX_ITERATIONS];
+ // Spawn ACE_MAX_PROCESSES processes which will contend for the
+ // lock.
+ ACE_Process servers[ACE_MAX_PROCESSES];
int i;
- for (i = 0; i < ACE_MAX_ITERATIONS; i++)
+ for (i = 0; i < ACE_MAX_PROCESSES; i++)
{
ACE_ASSERT (servers[i].start (s_argv) != -1);
ACE_DEBUG ((LM_DEBUG, "Server forked with pid = %d.\n", servers[i].getpid ()));
-
}
- for (i = 0; i < ACE_MAX_ITERATIONS; i++)
+ for (i = 0; i < ACE_MAX_PROCESSES; i++)
{
// Wait for the process we created to exit.
ACE_ASSERT (servers[i].wait () != -1);